@@ -1,4 +1,9 @@
+__all__ = ["main"]
+
 import getpass
+import os
+from argparse import ArgumentParser, Namespace
+from typing import Any
 
 import requests.exceptions
 
@@ -8,10 +13,10 @@ from darwin.exceptions import InvalidTeam, Unauthenticated, Unauthorized
 from darwin.options import Options
 
 
-def main():
+def main() -> Any:
     args, parser = Options().parse_args()
     try:
-        run(args, parser)
+        _run(args, parser)
     except Unauthorized:
         f._error("Your API key is not authorized to do that action.")
     except Unauthenticated:
@@ -22,16 +27,20 @@ def main():
         f._error("Darwin seems unreachable, please try again in a minute or contact support.")
 
 
-def run(args, parser):
+def _run(args: Namespace, parser: ArgumentParser) -> Any:
     if args.command == "help":
         f.help(parser)
     # Authenticate user
     if args.command == "authenticate":
-        api_key = getpass.getpass(prompt="API key: ", stream=None)
-        api_key = api_key.strip()
-        if api_key == "":
-            print("API Key needed, generate one for your team: https://darwin.v7labs.com/?settings=api-keys")
-            return
+        api_key = os.getenv("DARWIN_API_KEY")
+        if api_key:
+            print("Using API key from DARWIN_API_KEY")
+        else:
+            api_key = getpass.getpass(prompt="API key: ", stream=None)
+            api_key = api_key.strip()
+            if api_key == "":
+                print("API Key needed, generate one for your team: https://darwin.v7labs.com/?settings=api-keys")
+                return
         f.authenticate(api_key)
         print("Authentication succeeded.")
     # Select / List team
@@ -63,7 +72,7 @@ def run(args, parser):
         elif args.action == "url":
             f.url(args.dataset)
         elif args.action == "push":
-            f.upload_data(args.dataset, args.files, args.exclude, args.fps, args.path, args.frames)
+            f.upload_data(args.dataset, args.files, args.exclude, args.fps, args.path, args.frames, args.preserve_folders, args.verbose)
         # Remove a project (remotely)
         elif args.action == "remove":
             f.remove_remote_dataset(args.dataset)
@@ -72,7 +81,7 @@ def run(args, parser):
         elif args.action == "export":
             f.export_dataset(args.dataset, args.include_url_token, args.annotation_class, args.name)
         elif args.action == "files":
-            f.list_files(args.dataset, args.status, args.path, args.only_filenames)
+            f.list_files(args.dataset, args.status, args.path, args.only_filenames, args.sort_by)
         elif args.action == "releases":
             f.dataset_list_releases(args.dataset)
         elif args.action == "pull":
