@@ -1,11 +1,11 @@
 import concurrent.futures
 import time
+import multiprocessing
+import requests
 from dataclasses import dataclass
 from enum import Enum
 from pathlib import Path
 from typing import TYPE_CHECKING, Callable, List, Optional, Set, Tuple, Union
-
-import requests
 from darwin.path_utils import construct_full_path
 from darwin.utils import chunk
 from requests_toolbelt import MultipartEncoder, MultipartEncoderMonitor
@@ -108,6 +108,7 @@ class UploadHandler:
         multi_threaded: bool = True,
         progress_callback: Optional[ProgressCallback] = None,
         file_upload_callback: Optional[FileUploadCallback] = None,
+        max_workers: Optional[int] = None
     ):
         if not self._progress:
             self.prepare_upload()
@@ -128,7 +129,7 @@ class UploadHandler:
                     progress_callback(self.pending_count, 1)
 
         if multi_threaded:
-            with concurrent.futures.ThreadPoolExecutor(max_workers=5) as executor:
+            with concurrent.futures.ThreadPoolExecutor(max_workers=max_workers) as executor:
                 future_to_progress = {executor.submit(f, callback) for f in self.progress}
                 for future in concurrent.futures.as_completed(future_to_progress):
                     try:
