@@ -2,6 +2,8 @@ from dataclasses import dataclass, field
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Set
 
+from darwin.path_utils import construct_full_path
+
 Point = Dict[str, float]
 BoundingBox = Dict[str, float]
 Polygon = List[Point]
@@ -77,6 +79,11 @@ class AnnotationFile:
     workview_url: Optional[str] = None
     seq: Optional[int] = None
     frame_urls: Optional[List[str]] = None
+    remote_path: Optional[str] = None
+
+    @property
+    def full_path(self) -> str:
+        return construct_full_path(self.remote_path, self.filename)
 
 
 def make_bounding_box(class_name, x, y, w, h):
